@@ -9,7 +9,6 @@ from ._debug import log
 from ._version import __author__, __version__  # noqa: F401
 from .helpers import MONITOR_MANUFACTURER_CODES  # noqa: F401
 from .helpers import ScreenBrightnessError, logarithmic_range
-from .helpers import flatten_list  # noqa: F401  - deprecated.
 
 
 def get_brightness(
@@ -256,7 +255,9 @@ def fade_brightness(
     return get_brightness(**kwargs)
 
 
-def list_monitors_info(method: Optional[str] = None, allow_duplicates: bool = False) -> List[dict]:
+def list_monitors_info(
+    method: Optional[str] = None, allow_duplicates: bool = False, unsupported: bool = False
+) -> List[dict]:
     '''
     list detailed information about all monitors that are controllable by this library
 
@@ -264,6 +265,7 @@ def list_monitors_info(method: Optional[str] = None, allow_duplicates: bool = Fa
         method (str): the method to use to list the available monitors. See `get_methods` for
             more info on available methods
         allow_duplicates (bool): whether to filter out duplicate displays or not
+        unsupported (bool): include detected displays that are invalid or unsupported
 
     Returns:
         list: list of dictionaries
@@ -292,7 +294,9 @@ def list_monitors_info(method: Optional[str] = None, allow_duplicates: bool = Fa
             print('EDID:', monitor['edid'])
         ```
     '''
-    return _OS_MODULE.list_monitors_info(method=method, allow_duplicates=allow_duplicates)
+    return _OS_MODULE.list_monitors_info(
+        method=method, allow_duplicates=allow_duplicates, unsupported=unsupported
+    )
 
 
 def list_monitors(method: Optional[str] = None) -> List[str]:
