@@ -501,6 +501,7 @@ class I2C:
             cache_ident = '%s-%s-%s' % (device['name'], device['model'], device['serial'])
             if cache_ident not in cls._max_brightness_cache:
                 cls._max_brightness_cache[cache_ident] = max_value
+                log.debug(f'I2C {cache_ident} max brightness:{max_value} (current: {value})')
 
             if max_value != 100:
                 # if max value is not 100 then we have to adjust the scale to be
@@ -683,6 +684,63 @@ class XRandr:
     executable: str = 'xrandr'
     '''the xrandr executable to be called'''
 
+    @classmethod
+    def _gdi(cls):
+        '''
+        .. warning:: Don't use this
+           This function isn't final and I will probably make breaking changes to it.
+           You have been warned
+
+        Gets all displays reported by XRandr even if they're not supported
+        '''
+        xrandr_output = check_output([cls.executable, '--verbose']).decode().split('\n')
+
+        display_count = 0
+        tmp_display = {}
+
+        for line_index, line in enumerate(xrandr_output):
+            if line == '':
+                continue
+
+            if not line.startswith((' ', '\t')) and 'connected' in line and 'disconnected' not in line:
+                if tmp_display:
+                    yield tmp_display
+
+                tmp_display = {
+                    'name': line.split(' ')[0],
+                    'interface': line.split(' ')[0],
+                    'method': cls,
+                    'index': display_count,
+                    'model': None,
+                    'serial': None,
+                    'manufacturer': None,
+                    'manufacturer_id': None,
+                    'edid': None,
+                    'unsupported': line.startswith('XWAYLAND')
+                }
+                display_count += 1
+
+            elif 'EDID:' in line:
+                # extract the edid from the chunk of the output that will contain the edid
+                edid = ''.join(
+                    i.replace('\t', '') for i in xrandr_output[line_index + 1: line_index + 9]
+                )
+                tmp_display['edid'] = edid
+
+                for key, value in zip(
+                    ('manufacturer_id', 'manufacturer', 'model', 'name', 'serial'),
+                    EDID.parse(tmp_display['edid'])
+                ):
+                    if value is None:
+                        continue
+                    tmp_display[key] = value
+
+            elif 'Brightness:' in line:
+                tmp_display['brightness'] = int(float(line.replace('Brightness:', '')) * 100)
+
+        if tmp_display:
+            yield tmp_display
+
     @classmethod
     def get_display_info(cls, display: Optional[Union[int, str]] = None, brightness: bool = False) -> List[dict]:
         '''
@@ -715,62 +773,14 @@ class XRandr:
             benq_info = sbc.linux.XRandr.get_display_info('BenQ GL2450HM')[0]
             ```
         '''
-        def check_display(display):
-            if display:
-                if 'line' in display:
-                    del display['line']
-                return display['serial'] is None or '\\x' not in display['serial']
-            return False
-
-        xrandr_output = check_output([cls.executable, '--verbose']).decode().split('\n')
-
         valid_displays = []
-        display_count = 0
-        tmp_display = {}
-
-        for line_index, line in enumerate(xrandr_output):
-            if line == '':
+        for item in cls._gdi():
+            if item['unsupported']:
                 continue
-
-            if not line.startswith((' ', '\t')) and 'connected' in line and 'disconnected' not in line:
-                if check_display(tmp_display):
-                    valid_displays.append(tmp_display)
-
-                tmp_display = {
-                    'interface': line.split(' ')[0],
-                    'name': line.split(' ')[0],
-                    'line': line,
-                    'method': cls,
-                    'index': display_count,
-                    'model': None,
-                    'serial': None,
-                    'manufacturer': None,
-                    'manufacturer_id': None,
-                    'edid': None
-                }
-                display_count += 1
-
-            elif 'EDID:' in line:
-                # extract the edid from the chunk of the output that will contain the edid
-                edid = ''.join(
-                    i.replace('\t', '') for i in xrandr_output[line_index + 1: line_index + 9]
-                )
-                tmp_display['edid'] = edid
-
-                for key, value in zip(
-                    ('manufacturer_id', 'manufacturer', 'model', 'name', 'serial'),
-                    EDID.parse(tmp_display['edid'])
-                ):
-                    if value is None:
-                        continue
-                    tmp_display[key] = value
-
-            elif 'Brightness:' in line and brightness:
-                tmp_display['brightness'] = int(float(line.replace('Brightness:', '')) * 100)
-
-        if check_display(tmp_display):
-            valid_displays.append(tmp_display)
-
+            if not brightness:
+                del item['brightness']
+            del item['unsupported']
+            valid_displays.append(item)
         if display is not None:
             valid_displays = filter_monitors(display=display, haystack=valid_displays, include=['interface'])
         return valid_displays
@@ -844,6 +854,100 @@ class DDCUtil:
     _max_brightness_cache: dict = {}
     '''Cache for monitors and their maximum brightness values'''
 
+    @classmethod
+    def _gdi(cls):
+        '''
+        .. warning:: Don't use this
+           This function isn't final and I will probably make breaking changes to it.
+           You have been warned
+
+        Gets all displays reported by DDCUtil even if they're not supported
+        '''
+        raw_ddcutil_output = str(
+            check_output(
+                [
+                    cls.executable, 'detect', '-v', '--async',
+                    f'--sleep-multiplier={cls.sleep_multiplier}'
+                ], max_tries=10
+            )
+        )[2:-1].split('\\n')
+        # Use -v to get EDID string but this means output cannot be decoded.
+        # Or maybe it can. I don't know the encoding though, so let's assume it cannot be decoded.
+        # Use str()[2:-1] workaround
+
+        # include "Invalid display" sections because they tell us where one displays metadata ends
+        # and another begins. We filter out invalid displays later on
+        ddcutil_output = [i for i in raw_ddcutil_output if i.startswith(('Invalid display', 'Display', '\t', ' '))]
+        tmp_display = {}
+        display_count = 0
+
+        for line_index, line in enumerate(ddcutil_output):
+            if not line.startswith(('\t', ' ')):
+                if tmp_display:
+                    yield tmp_display
+
+                tmp_display = {
+                    'method': cls,
+                    'index': display_count,
+                    'model': None,
+                    'serial': None,
+                    'bin_serial': None,
+                    'manufacturer': None,
+                    'manufacturer_id': None,
+                    'edid': None,
+                    'unsupported': 'invalid display' in line.lower()
+                }
+                display_count += 1
+
+            elif 'I2C bus' in line:
+                tmp_display['i2c_bus'] = line[line.index('/'):]
+                tmp_display['bus_number'] = int(tmp_display['i2c_bus'].replace('/dev/i2c-', ''))
+
+            elif 'Mfg id' in line:
+                # Recently ddcutil has started reporting manufacturer IDs like
+                # 'BNQ - UNK' or 'MSI - Microstep' so we have to split the line
+                # into chunks of alpha chars and check for a valid mfg id
+                for code in re.split(r'[^A-Za-z]', line.replace('Mfg id:', '').replace(' ', '')):
+                    if len(code) != 3:
+                        # all mfg ids are 3 chars long
+                        continue
+
+                    try:
+                        (
+                            tmp_display['manufacturer_id'],
+                            tmp_display['manufacturer']
+                        ) = _monitor_brand_lookup(code)
+                    except TypeError:
+                        continue
+                    else:
+                        break
+
+            elif 'Model' in line:
+                # the split() removes extra spaces
+                name = line.replace('Model:', '').split()
+                try:
+                    tmp_display['model'] = name[1]
+                except IndexError:
+                    pass
+                tmp_display['name'] = ' '.join(name)
+
+            elif 'Serial number' in line:
+                tmp_display['serial'] = line.replace('Serial number:', '').replace(' ', '') or None
+
+            elif 'Binary serial number:' in line:
+                tmp_display['bin_serial'] = line.split(' ')[-1][3:-1]
+
+            elif 'EDID hex dump:' in line:
+                try:
+                    tmp_display['edid'] = ''.join(
+                        ''.join(i.split()[1:17]) for i in ddcutil_output[line_index + 2: line_index + 10]
+                    )
+                except Exception:
+                    pass
+
+        if tmp_display:
+            yield tmp_display
+
     @classmethod
     def get_display_info(cls, display: Optional[Union[int, str]] = None) -> List[dict]:
         '''
@@ -875,99 +979,15 @@ class DDCUtil:
             benq_info = sbc.linux.DDCUtil.get_display_info('BenQ GL2450HM')[0]
             ```
         '''
-        def check_display(tmp_display):
-            if tmp_display and 'Invalid display' not in tmp_display['line']:
-                del tmp_display['line']
-                return True
-            return False
-
         valid_displays = __cache__.get('ddcutil_monitors_info')
         if valid_displays is None:
-            raw_ddcutil_output = str(
-                check_output(
-                    [
-                        cls.executable, 'detect', '-v', '--async',
-                        f'--sleep-multiplier={cls.sleep_multiplier}'
-                    ], max_tries=10
-                )
-            )[2:-1].split('\\n')
-            # Use -v to get EDID string but this means output cannot be decoded.
-            # Or maybe it can. I don't know the encoding though, so let's assume it cannot be decoded.
-            # Use str()[2:-1] workaround
-
-            # include "Invalid display" sections because they tell us where one displays metadata ends
-            # and another begins. We filter out invalid displays later on
-            ddcutil_output = [i for i in raw_ddcutil_output if i.startswith(('Invalid display', 'Display', '\t', ' '))]
             valid_displays = []
-            tmp_display = {}
-            display_count = 0
+            for item in cls._gdi():
+                if item['unsupported']:
+                    continue
+                del item['unsupported']
+                valid_displays.append(item)
 
-            for line_index, line in enumerate(ddcutil_output):
-                if not line.startswith(('\t', ' ')):
-                    if check_display(tmp_display):
-                        valid_displays.append(tmp_display)
-
-                    tmp_display = {
-                        'line': line,
-                        'method': cls,
-                        'index': display_count,
-                        'model': None,
-                        'serial': None,
-                        'bin_serial': None,
-                        'manufacturer': None,
-                        'manufacturer_id': None,
-                        'edid': None
-                    }
-                    display_count += 1
-
-                elif 'I2C bus' in line:
-                    tmp_display['i2c_bus'] = line[line.index('/'):]
-                    tmp_display['bus_number'] = int(tmp_display['i2c_bus'].replace('/dev/i2c-', ''))
-
-                elif 'Mfg id' in line:
-                    # Recently ddcutil has started reporting manufacturer IDs like
-                    # 'BNQ - UNK' or 'MSI - Microstep' so we have to split the line
-                    # into chunks of alpha chars and check for a valid mfg id
-                    for code in re.split(r'[^A-Za-z]', line.replace('Mfg id:', '').replace(' ', '')):
-                        if len(code) != 3:
-                            # all mfg ids are 3 chars long
-                            continue
-
-                        try:
-                            (
-                                tmp_display['manufacturer_id'],
-                                tmp_display['manufacturer']
-                            ) = _monitor_brand_lookup(code)
-                        except TypeError:
-                            continue
-                        else:
-                            break
-
-                elif 'Model' in line:
-                    # the split() removes extra spaces
-                    name = line.replace('Model:', '').split()
-                    try:
-                        tmp_display['model'] = name[1]
-                    except IndexError:
-                        pass
-                    tmp_display['name'] = ' '.join(name)
-
-                elif 'Serial number' in line:
-                    tmp_display['serial'] = line.replace('Serial number:', '').replace(' ', '') or None
-
-                elif 'Binary serial number:' in line:
-                    tmp_display['bin_serial'] = line.split(' ')[-1][3:-1]
-
-                elif 'EDID hex dump:' in line:
-                    try:
-                        tmp_display['edid'] = ''.join(
-                            ''.join(i.split()[1:17]) for i in ddcutil_output[line_index + 2: line_index + 10]
-                        )
-                    except Exception:
-                        pass
-
-            if check_display(tmp_display):
-                valid_displays.append(tmp_display)
             if valid_displays:
                 __cache__.store('ddcutil_monitors_info', valid_displays)
 
@@ -1025,6 +1045,7 @@ class DDCUtil:
                 cache_ident = '%s-%s-%s' % (monitor['name'], monitor['serial'], monitor['bin_serial'])
                 if cache_ident not in cls._max_brightness_cache:
                     cls._max_brightness_cache[cache_ident] = max_value
+                    log.debug(f'DDCUtil: {cache_ident} max brightness:{max_value} (current: {value})')
 
                 __cache__.store(f'ddcutil_brightness_{monitor["index"]}', value, expires=0.5)
             try:
@@ -1077,7 +1098,9 @@ class DDCUtil:
             )
 
 
-def list_monitors_info(method: Optional[str] = None, allow_duplicates: bool = False) -> List[dict]:
+def list_monitors_info(
+    method: Optional[str] = None, allow_duplicates: bool = False, unsupported: bool = False
+) -> List[dict]:
     '''
     Lists detailed information about all detected monitors
 
@@ -1085,6 +1108,7 @@ def list_monitors_info(method: Optional[str] = None, allow_duplicates: bool = Fa
         method (str): the method the monitor can be addressed by. See `screen_brightness_control.get_methods`
             for more info on available methods
         allow_duplicates (bool): whether to filter out duplicate displays (displays with the same EDID) or not
+        unsupported (bool): include detected displays that are invalid or unsupported
 
     Returns:
         list: list of dicts
@@ -1130,7 +1154,10 @@ def list_monitors_info(method: Optional[str] = None, allow_duplicates: bool = Fa
         if method is not None and method != method_class.__name__.lower():
             continue
         try:
-            haystack += method_class.get_display_info()
+            if unsupported and hasattr(method_class, '_gdi'):
+                haystack += method_class._gdi()
+            else:
+                haystack += method_class.get_display_info()
         except Exception as e:
             log.debug(f'error grabbing display info from {method_class} - {type(e).__name__}: {e}')
             pass
